summaryrefslogtreecommitdiffstats
path: root/src/include/eiotas_room.h
diff options
context:
space:
mode:
authorJérémy Zurcher <jeremy@asynk.ch>2012-05-29 17:09:40 +0200
committerJérémy Zurcher <jeremy@asynk.ch>2012-05-29 17:09:40 +0200
commit9aee0986af098e355eec2c9d87ac4e3fc3fdcb42 (patch)
tree09f0165226b2f8711a4730abfdf2e7c4d35ce474 /src/include/eiotas_room.h
parent823df95bd73bf7195d9a9d3dacd418475c055bc8 (diff)
downloadedoors-9aee0986af098e355eec2c9d87ac4e3fc3fdcb42.zip
edoors-9aee0986af098e355eec2c9d87ac4e3fc3fdcb42.tar.gz
documentation
Diffstat (limited to 'src/include/eiotas_room.h')
-rw-r--r--src/include/eiotas_room.h32
1 files changed, 22 insertions, 10 deletions
diff --git a/src/include/eiotas_room.h b/src/include/eiotas_room.h
index 644dc0e..c265344 100644
--- a/src/include/eiotas_room.h
+++ b/src/include/eiotas_room.h
@@ -25,39 +25,51 @@
/**
* @typedef Eiotas_Room
* Type for a Room, which holds other child Eiotas_Iotas.
*/
typedef struct _Eiotas_Room Eiotas_Room;
/**
* @struct _Eiotas_Room
* Struct for a Room, which holds other child Eiotas_Iotas.
*/
struct _Eiotas_Room {
- Eiotas_Iota iota; /**< Eiotas_Iota structural info */
+ Eiotas_Iota iota; /**< @ref Eiotas_Iota structural info */
Eina_Hash *links; /**< TODO */
- Eina_Hash *children; /**< stringshared values optimized hash table holding Eiotas_Iotas */
+ Eina_Hash *children; /**< stringshared values optimized hash table holding @ref Eiotas_Iota */
};
/**
+ * @defgroup Eiotas_Room Eiotas_Room
+ *
+ * A Eiota_Room may hold children @ref Eiotas_Room or @ref Eiotas_Door (@ref Eiotas_Board).
+ *
+ * @{
+ */
+
+/**
* @brief Free allocated resources.
*
* @param room The Eiotas_Room to free.
*
* This function will free all it's child Eiotas_Iotas.
*/
void eiotas_room_free(Eiotas_Room *room);
/**
* @brief Print iota information using EINA_LOG_DBG.
*
* @param name The name of this Eiotas_Iota.
* @param parent The direct hierarchical parent Eiotas_Room.
*
* @return the new Eiotas_Room, @c NULL on failure
*
* This function will register the new room as a child of it's parent Eiotas_Room.
*/
EAPI Eiotas_Room* eiotas_room_add(const char* name, Eiotas_Room *parent);
+/**
+ * @}
+ */
+
#endif // __EIOTAS_ROOM_H__
@@ -25,39 +25,51 @@
/**
* @typedef Eiotas_Room
- * Type for a Room, which holds other child Eiotas_Iotas.
+ * Type for a Room, which holds other child @ref Eiotas_Iota.
*/
typedef struct _Eiotas_Room Eiotas_Room;
@@ -25,39 +25,51 @@
/**
* @struct _Eiotas_Room
- * Struct for a Room, which holds other child Eiotas_Iotas.
+ * Struct for a Room, which holds other child @ref Eiotas_Iota.
*/
struct _Eiotas_Room {
@@ -25,39 +25,51 @@
* @brief Free allocated resources.
*
- * @param room The Eiotas_Room to free.
+ * @param room The @ref Eiotas_Room to free.
*
@@ -25,39 +25,51 @@
*
- * This function will free all it's child Eiotas_Iotas.
+ * This function will free all it's child @ref Eiotas_Iota.
*/
void eiotas_room_free(Eiotas_Room *room);
@@ -25,39 +25,51 @@
* @brief Print iota information using EINA_LOG_DBG.
*
- * @param name The name of this Eiotas_Iota.
- * @param parent The direct hierarchical parent Eiotas_Room.
+ * @param name The name of this @ref Eiotas_Iota.
+ * @param parent The direct hierarchical parent @ref Eiotas_Room.
*
@@ -25,39 +25,51 @@
*
- * @return the new Eiotas_Room, @c NULL on failure
+ * @return the new @ref Eiotas_Room, @c NULL on failure
*
@@ -25,39 +25,51 @@
*
- * This function will register the new room as a child of it's parent Eiotas_Room.
+ * This function will register the new room as a child of it's parent @ref Eiotas_Room.
*/
EAPI Eiotas_Room* eiotas_room_add(const char* name, Eiotas_Room *parent);